@@ -24,9 +24,9 @@
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 # 02110-1301 USA
 #
-# $Id: AptRepoClient.py 68 2007-05-10 19:19:48Z kad $
+# $Id: AptRepoClient.py 82 2007-11-11 23:01:26Z kad $
 
-__revision__ = "r"+"$Revision: 68 $"[11:-2]
+__revision__ = "r"+"$Revision: 82 $"[11:-2]
 __all__ = [ 'AptRepoClient', 'AptRepoException' ]
 
 from minideblib.DpkgControl import DpkgParagraph
@@ -169,11 +169,12 @@ class AptRepoParagraph(DpkgParagraph):
 
 
 class AptRepoMetadataBase(DpkgOrderedDatalist):
-    def __init__(self, base_url = None, case_sensitive = 0):
+    def __init__(self, base_url = None, case_sensitive = 0, allowed_arches = None):
         DpkgOrderedDatalist.__init__(self)
         self.key = "package"
         self.case_sensitive = case_sensitive
         self.base_url = base_url
+        self.allowed_arches = allowed_arches
 
     def setkey(self, key):
         self.key = key
@@ -196,6 +197,13 @@ class AptRepoMetadataBase(DpkgOrderedDatalist):
             para = self.__load_one(inf, base_url)
             if not para: 
                 break
+            
+            if 'architecture' in para and \
+                para['architecture'] not in [ "all", "any" ] and \
+                self.allowed_arches and \
+                self.allowed_arches != [ "all" ] and \
+                not [arch for arch in para['architecture'].split() if arch in self.allowed_arches]:
+                    continue
             if para[self.key] not in self:
                 self[para[self.key]] = []
             self[para[self.key]].append(para)
@@ -463,7 +471,10 @@ class AptRepoClient(LoggableObject):
         def filter_repolines(repolines):
             """Return filtered list of repos after removing comments and whitespace"""
             def filter_repoline(repoline):
-                """ Get rid of all comments and whitespace """
+                """ Get rid of all comments and whitespace."""
+                # Replace "copy:" method to "file:"
+                repoline = re.sub("(\s)copy:", "\\1file:", repoline)
+                # Strip comments and spaces
                 repos = repoline.split("#")[0].strip()
                 return (repos and [repos] or [None])[0]
             temp = []
@@ -511,7 +522,7 @@ class AptRepoClient(LoggableObject):
         
         for (url, distro, section) in repourls:
             if (base_url, distro, section) not in dest_dict:
-                dest_dict[(base_url, distro, section)] = AptRepoMetadataBase(base_url)
+                dest_dict[(base_url, distro, section)] = AptRepoMetadataBase(base_url, allowed_arches=self._arch)
             dest = dest_dict[(base_url, distro, section)]
         
             # Let's check .gz variant first
